@@ -53,7 +53,7 @@ $example->Blur('0.0x1.0');
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Border');
-$example->Border(color=>'gold');
+$example->Border(geometry=>'6x6',color=>'gold');
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Channel');
@@ -103,7 +103,7 @@ push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Explode');
 $example->Set(background=>'#000000FF');
-$example->Implode(-10);
+$example->Implode(-1);
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Flip');
@@ -137,7 +137,7 @@ $example->Quantize(colorspace=>'gray');
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Implode');
-$example->Implode(30);
+$example->Implode(0.5);
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Median Filter');
@@ -212,6 +212,11 @@ $example->Label('Sharpen');
 $example->Sharpen('0.0x1.0');
 push(@$images,$example);
 $example=$model->Clone();
+$example->Label('Shave');
+$example->Shave('10x10');
+push(@$images,$example);
+$example=$model->Clone();
+$example=$model->Clone();
 $example->Label('Shear');
 $example->Shear('45x45');
 $example->Transparent(color=>'black');
@@ -255,4 +260,4 @@ print "Write image...\n";
 $montage->Set(matte=>'false');
 $montage->Write('demo.jpg');
 print "Display image...\n";
-$montage->display();
+$montage->Write('win:');
